@@ -117,7 +117,7 @@ class Products extends CGExtensions
 
   function GetVersion()
   {
-	return '2.10.3';
+	return '2.10.5';
   }
 
   function MinimumCMSVersion()
@@ -205,6 +205,8 @@ EOT;
 	$this->SetParameterType('fieldid',CLEAN_INT);
 	$this->SetParameterType('fieldval',CLEAN_STRING);
 	$this->CreateParameter('fieldval','',$this->Lang('param_fieldval'));
+	$this->SetParameterType('categoryfield',CLEAN_STRING);
+	$this->CreateParameter('categoryfield','',$this->Lang('param_categoryfield'));
 
 	$this->CreateParameter('inline',0,$this->Lang('param_inline'));
 	$this->SetParameterType('inline',CLEAN_INT);
