@@ -73,8 +73,8 @@ if (isset($params['detailpage']))
   }
 if( !empty($detailpage) )
   {
-    $manager =& $gCms->GetHierarchyManager();
-    $node =& $manager->sureGetNodeByAlias($detailpage);
+    $manager = $gCms->GetHierarchyManager();
+    $node = $manager->sureGetNodeByAlias($detailpage);
     if (isset($node))
       {
 	$content =& $node->GetContent();	
