@@ -72,7 +72,7 @@ $sortby     = get_preference($uid,'products_sel_sortby','create_date');
 $sortorder  = get_preference($uid,'products_sel_sortorder','desc');
 $categories = '';
 $tmp= get_preference($uid,'products_sel_categories','');
-if( !empty($tmp) ) $categories = explode(',',$categories);
+if( !empty($tmp) ) $categories = explode(',',$tmp);
 $custom_fields = '';
 $tmp = get_preference('uid','products_sel_customfields','');
 if( !empty($tmp) ) $custom_fields = explode(',',$tmp);
@@ -220,7 +220,7 @@ if( is_array($custom_fields) && count($custom_fields) && count($fields_viewable)
     for( $j = 0; $j < count($custom_fields); $j++ )
       {
 	$fid = $custom_fields[$j];
-	$fields[] = "Fv{$j}.value AS Fld__{$field_names[$fid]}";
+	$fields[] = "Fv{$j}.value AS 'Fld__{$field_names[$fid]}'";
 	$joins[] = 'LEFT OUTER JOIN '.cms_db_prefix()."module_products_fieldvals Fv{$j}
                     ON Fv{$j}.product_id = p.id AND Fv{$j}.fielddef_id = ?";
 	$qparms[] = $custom_fields[$j];
